import datetime as dt
from _decimal import Decimal
from unittest.mock import patch

import zeep

from enedis.data_models.consulterdonneespoint import DonneesConsulterPoint
from enedis.services.consulter_point import ConsulterPoint
from proxy.tests.services.ServicesTestCase import raise_transport_errror, ServicesTestCase


class TestConsulterPoint(ServicesTestCase):
    maxDiff = None

    expected_response = {'header': {'acquittement': None}, 'body': {'point': {'donneesGenerales': {
        'etatContractuel': {'libelle': 'string', 'code': 'IMPRO'}, 'adresseInstallation':
            {'escalierEtEtageEtAppartement': 'string', 'batiment': 'string',
             'numeroEtNomVoie': 'string', 'lieuDit': 'string', 'codePostal': 'string',
             'commune': {'libelle': 'string', 'code': 'string'}},
        'alimentationComplementaire': False, 'alimentationSecours': False, 'bornePoste':
            True, 'borneFixe': False, 'hebergeurDecomptant': {'libelle': 'string',
                                                              'code': 'DECO'},
        'regroupementTurpe': {'libelle': 'string', 'code': 'NON'},
        'dateDerniereModificationFormuleTarifaireAcheminement': dt.date(2011, 12,
                                                                        4),
        'dateDerniereModificationCalendrierFournisseur': dt.date(2003, 4, 20),
        'dateDerniereModificationGroupePeriodeMobile': dt.date(2014, 12, 2),
        'dateDerniereAugmentationPuissanceSouscrite': dt.date(2012, 7, 23),
        'dateDerniereDiminutionPuissanceSouscrite': dt.date(2010, 7, 29),
        'datePremierePoseCompteurLinky': dt.date(2018, 12, 27), 'segment': {
            'libelle': 'string', 'code': 'C2'}, 'numTelephoneDepannage': 'string',
        'niveauOuvertureServices': 'string', 'sensible': True,
        'autoconsommationIndividuelle': {'libelle': 'string', 'code': 'string'},
        'rattachements': {'rattachement': [{'type': {'libelle': 'string',
                                                     'code': 'string'}, 'dateDebut': dt.date(2006, 3, 19), 'dateFin':
                                                dt.date(2008, 1, 24), 'pointsConfondus': True, 'longueursLiaisons': {
            'longueurLiaisonAerienneHta': {'valeur': Decimal('1000.000000000000000'),
                                           'unite': 'm'}, 'longueurLiaisonSouterraineHta': {'valeur': Decimal(
                '1000.000000000000000'), 'unite': 'km'}}, 'pointsRattaches': {'pointRattache': [{
            'role': {'libelle': 'string', 'code': 'string'}, 'puissanceMaxAppelee': {
                'valeur': Decimal('1000.000000000000000'), 'unite': 'kVA'}, 'finalites': {
                'finalite': [{'libelle': 'string', 'code': 'string'}]}, 'id': 'string'}]}}]}},
        'situationAlimentation': {'etatAlimentation': {'libelle': 'string',
                                                       'code': 'NRAC'},
                                  'alimentationPrincipale': {'domaineTension': {'libelle':
                                                                                    'string', 'code': 'BTSUP'},
                                                             'tensionLivraison': {'libelle': 'string',
                                                                                  'code': 'string'},
                                                             'nbFilsBranchement': 100, 'modeApresCompteur': {'libelle':
                                                                                                                 'string',
                                                                                                             'code': 'string'},
                                                             'longueursLiaisons': {'longueurLiaisonAerienne': {
                                                                 'valeur': Decimal('1000.000000000000000'),
                                                                 'unite': 'km'},
                                                                 'longueurLiaisonSouterraine': {
                                                                     'valeur': Decimal('1000.000000000000000'),
                                                                     'unite': 'm'}},
                                                             'puissanceRaccordementSoutirage': {'valeur': Decimal(
                                                                 '1000.000000000000000'), 'unite': 'kVA'},
                                                             'puissanceLimiteSoutirage': {'valeur':
                                                                 Decimal(
                                                                     '1000.000000000000000'),
                                                                 'unite': 'kWc'},
                                                             'zoneQualiteDesserte': {
                                                                 'libelle': 'string', 'code': 'string'},
                                                             'installationClient': {
                                                                 'nbMoyensProductionAutonome': 100,
                                                                 'puissanceTotaleProductionAutonome': {
                                                                     'valeur': Decimal('1000.000000000000000'),
                                                                     'unite': 'kVA'},
                                                                 'modeCouplageProductionAutonome': {'libelle': 'string',
                                                                                                    'code': 'string'},
                                                                 'dispositifParticulierLimitationPerturbations': 'string'}},
                                  'alimentationsComplementaires': {'alimentationComplementaire': [{
                                      'domaineTension': {'libelle': 'string', 'code': 'BTSUP'}, 'tensionLivraison': {
                                          'libelle': 'string', 'code': 'string'}, 'longueursLiaisons': {
                                          'longueurLiaisonAerienne': {'valeur': Decimal('1000.000000000000000'),
                                                                      'unite': 'm'},
                                          'longueurLiaisonSouterraine': {'valeur': Decimal(
                                              '1000.000000000000000'), 'unite': 'm'}}, 'nbCellules': 100,
                                      'puissanceRaccordementSoutirage': {'valeur': Decimal('1000.000000000000000'),
                                                                         'unite': 'kVAR'}}]},
                                  'alimentationsSecours': {'alimentationSecours': [{
                                      'domaineTension': {'libelle': 'string', 'code': 'HTB'}, 'tensionLivraison': {
                                          'libelle': 'string', 'code': 'string'}, 'longueursLiaisons': {
                                          'longueurLiaisonAerienne': {'valeur': Decimal('1000.000000000000000'),
                                                                      'unite': 'm'},
                                          'longueurLiaisonSouterraine': {'valeur': Decimal(
                                              '1000.000000000000000'), 'unite': 'm'}},
                                      'transformateurDifferentPrincipal':
                                          True, 'puissanceReserveeHt': {'valeur': Decimal('1000.000000000000000'),
                                                                        'unite': 'kWc'},
                                      'puissanceReserveeBt': {'valeur': Decimal(
                                          '1000.000000000000000'), 'unite': 'kW'}, 'modeBasculePrincipaleSecours': {
                                          'libelle': 'string', 'code': 'string'}, 'prorataPuissance': Decimal(
                                          '1000.000000000000000'), 'nbCellules': 100, 'alimentationGarantie': True}]},
                                  'coupure': {'dateDebut': dt.date(2010, 8, 31), 'motif': {'libelle':
                                                                                               'string',
                                                                                           'code': 'string'},
                                              'localisation': {'libelle': 'string',
                                                               'code': 'string'}},
                                  'limitation': {'puissanceLimitee': {'valeur': Decimal(
                                      '1000.000000000000000'), 'unite': 'kVAR'}, 'typeLimiteur': {'libelle': 'string',
                                                                                                  'code': 'string'}}},
        'situationComptage': {'dispositifComptage': {'typeComptage':
                                                         {'libelle': 'string', 'code': 'string'},
                                                     'compteurs': {'compteur': [{
                                                         'numeroSerie': 'string',
                                                         'localisation': {'libelle': 'string', 'code': 'string'},
                                                         'accessibilite': True, 'regimePropriete': {'libelle': 'string',
                                                                                                    'code': 'string'},
                                                         'modeleCompteur': {'typeAppareil': 'string', 'sousType': {
                                                             'libelle': 'string', 'code': 'string'},
                                                                            'anneeFabrication': (2007, None),
                                                                            'nbRoues': 100, 'nbCadrans': 100},
                                                         'matricule': 'string', 'tensionCompteur': {
                                                             'libelle': 'string', 'code': 'string'},
                                                         'puissanceMax': {'valeur': Decimal(
                                                             '1000.000000000000000'), 'unite': 'kVA'},
                                                         'nombreFils': 100, 'intensiteNominale':
                                                             {'libelle': 'string', 'code': 'string'},
                                                         'ticActivee': False, 'ticStandard':
                                                             False, 'ticActivable': True,
                                                         'plagesHeuresCreuses': 'string',
                                                         'periodeDeploiementLinky': 'string',
                                                         'parametresTeleAcces': {'numeroTelephone':
                                                                                     'string',
                                                                                 'numeroVoieAiguillage': 100,
                                                                                 'cle': 'string',
                                                                                 'etatLigneTelephonique':
                                                                                     'string', 'fenetreEcouteClient': {
                                                                 'heureDebut': dt.time(4, 57, 17),
                                                                 'duree': {'valeur': Decimal('1000.000000000000000'),
                                                                           'unite': 's'}}},
                                                         'programmationHoraire': {
                                                             'programmationPosteHoraire': [{'libelle': 'string',
                                                                                            'periodesHoraires': 'string',
                                                                                            'code': 'string'}]},
                                                         'coefficientLecture': Decimal(
                                                             '1000.000000000000000'), 'eligiblePeriodeMobile': False}]},
                                                     'grilleFrn': {
                                                         'calendrier': {'libelle': 'string', 'code': 'string'}},
                                                     'presenceBtr': True,
                                                     'disjoncteur': {
                                                         'localisation': {'libelle': 'string', 'code': 'string'},
                                                         'accessibilite': False,
                                                         'regimePropriete': {'libelle': 'string',
                                                                             'code': 'string'},
                                                         'nature': {'libelle': 'string', 'code': 'string'},
                                                         'intensiteReglage': {'valeur': Decimal('1000.000000000000000'),
                                                                              'unite': 'A'},
                                                         'calibre': {'libelle': 'string', 'code': 'string'},
                                                         'nbPoles': 100}, 'relais': {
                'regimePropriete': {'libelle': 'string', 'code': 'string'}, 'nature': {'libelle':
                                                                                           'string', 'code': 'string'},
                'typeCommande': {'libelle': 'string',
                                 'code': 'string'}, 'plageHeuresCreuses': 'string'}, 'transformateurCourant': {
                'localisation': {'libelle': 'string', 'code': 'string'}, 'accessibilite': False,
                'regimePropriete': {'libelle': 'string', 'code': 'string'}, 'calibre': {
                    'libelle': 'string', 'code': 'string'}, 'couplage': {'libelle': 'string',
                                                                         'code': 'string'},
                'classePrecision': {'libelle': 'string', 'code': 'string'},
                'position': {'libelle': 'string', 'code': 'string'}}, 'transformateurTension': {
                'localisation': {'libelle': 'string', 'code': 'string'}, 'accessibilite': False,
                'regimePropriete': {'libelle': 'string', 'code': 'string'}, 'calibre': {
                    'libelle': 'string', 'code': 'string'}, 'couplage': {'libelle': 'string',
                                                                         'code': 'string'},
                'classePrecision': {'libelle': 'string', 'code': 'string'}},
                                                     'facteurCorrectifPertesJoule': Decimal('1000.000000000000000'),
                                                     'facteurCorrectifPertesFer': Decimal('1000.000000000000000'),
                                                     'facteurCorrectifPertesReactives': Decimal('1000.000000000000000'),
                                                     'particularite': {'libelle': 'string', 'code': 'string'},
                                                     'tensionComptage': {
                                                         'libelle': 'string', 'code': 'string'}},
                              'caracteristiquesReleve': {
                                  'modeTraitement': {'libelle': 'string', 'code': 'string'}, 'periodicite': {
                                      'libelle': 'string', 'code': 'string'}, 'dureeCycle': {'valeur': Decimal(
                                      '1000.000000000000000'), 'unite': 'min'}, 'plageReleve': {'libelle': 'string',
                                                                                                'code': 'string'}},
                              'modeReleve': {'libelle': 'string', 'code': 'string'},
                              'mediaReleve': {'libelle': 'string', 'code': 'string'},
                              'futuresPlagesHeuresCreuses': {'libelle': 'string', 'code': 'string'},
                              'futuresProgrammationsHoraires': {'formuleTarifaireAcheminement': [{'libelle':
                                                                                                      'string',
                                                                                                  'programmationHoraire': {
                                                                                                      'programmationPosteHoraire': [
                                                                                                          {'libelle':
                                                                                                               'string',
                                                                                                           'periodesHoraires': 'string',
                                                                                                           'code': 'string'}]},
                                                                                                  'code': 'string'}]},
                              'teleoperable': True, 'enregistrementCourbeDeCharge': False},
        'situationContractuelle': {'dateDebut': dt.date(2011, 4, 14), 'dateFin':
            dt.date(2003, 8, 19), 'contratId': 'string', 'clientFinal': {'categorie': {
            'libelle': 'string', 'code': 'PRO'}, 'typeResidence': {'libelle': 'string',
                                                                   'code': 'SEC'}, 'refFournisseur': 'string',
            'personnePhysique': {'civilite':
                                     'string', 'nom': 'string', 'prenom': 'string'}, 'personneMorale': None,
            'adressePostale': {'ligne1': 'string', 'ligne2': 'string', 'ligne3': 'string',
                               'ligne4': 'string', 'ligne5': 'string', 'ligne6': 'string', 'ligne7': 'string'},
            'coordonneesContact': {'numTelephone1': 'string', 'numTelephone2': 'string',
                                   'numFax': 'string', 'adresseEmail': 'string'}}, 'interlocuteurClient': {
            'personnePhysique': {'civilite': 'string', 'nom': 'string', 'prenom': 'string'},
            'personneMorale': None, 'adressePostale': {'ligne1': 'string', 'ligne2':
                'string', 'ligne3': 'string', 'ligne4': 'string', 'ligne5': 'string',
                                                       'ligne6': 'string', 'ligne7': 'string'},
            'coordonneesContact': {'numTelephone1':
                                       'string', 'numTelephone2': 'string', 'numFax': 'string', 'adresseEmail':
                                       'string'}}, 'interlocuteurTechnique': {'personnePhysique': {'civilite': 'string',
                                                                                                   'nom': 'string',
                                                                                                   'prenom': 'string'},
                                                                              'personneMorale': None,
                                                                              'adressePostale': {
                                                                                  'ligne1': 'string',
                                                                                  'ligne2': 'string',
                                                                                  'ligne3': 'string',
                                                                                  'ligne4': 'string',
                                                                                  'ligne5': 'string',
                                                                                  'ligne6': 'string',
                                                                                  'ligne7': 'string'},
                                                                              'coordonneesContact': {
                                                                                  'numTelephone1': 'string',
                                                                                  'numTelephone2': 'string',
                                                                                  'numFax': 'string',
                                                                                  'adresseEmail': 'string'}},
                                   'structureTarifaire': {
                                       'formuleTarifaireAcheminement': {'libelle': 'string', 'code': 'string'},
                                       'longueUtilisation': {'contexte': {'libelle': 'string', 'code': 'string'},
                                                             'forfait': {'valeur': Decimal('1000.000000000000000'),
                                                                         'unite': 'jour'}},
                                       'codeTarifAcheminement': 'string', 'puissanceSouscriteMax': {'valeur': Decimal(
                                           '1000.000000000000000'), 'unite': 'kW'}, 'denivelePuissances': {
                                           'classesTemporelles': {
                                               'classeTemporelle': [{'libelle': 'string', 'puissance': {
                                                   'valeur': Decimal('1000.000000000000000'), 'unite': 'kVAR'},
                                                                     'code': 'string'}]}},
                                       'calendrierFrn': {'libelle': 'string', 'code': 'string'},
                                       'groupePeriodeMobile': {'libelle': 'string', 'code': 'string'}}, 'siContractuel':
                                       {'libelle': 'string', 'code': 'string'}}, 'optionsContractuellesSouscrites': {
            'engagementQualiteFourniture': [{'dateSouscription': dt.date(2011, 7, 22),
                                             'dateResiliation': dt.date(2004, 3, 3), 'dureeCreux': {'valeur': Decimal(
                    '1000.000000000000000'), 'unite': 'jour'}, 'periodicite': {'libelle': 'string',
                                                                               'code': 'string'}, 'nbCreux': 100,
                                             'profondeurCreux': Decimal(
                                                 '1000.000000000000000'), 'dateReferenceCreux': dt.date(2017, 8, 12),
                                             'id': 201}], 'telecommandeInterrupteurs': [{'dateSouscription': dt.date(
                2009, 7, 12), 'dateResiliation': dt.date(2018, 8, 2), 'nbDirections':
                100}], 'protectionsChantier': [{'dateSouscription': dt.date(2001, 10, 24),
                                                'dateResiliation': dt.date(2001, 2, 20), 'nbPortees': 100}],
            'courbesCharge': [{'dateSouscription': dt.date(2017, 9, 14),
                               'dateResiliation': dt.date(2008, 4, 17), 'transmission': True,
                               'utilisationRecoflux': False, 'periodicite': {'valeur': Decimal(
                    '1000.000000000000000'), 'unite': 'min'}, 'pasCourbeCharge': {'valeur': Decimal(
                    '1000.000000000000000'), 'unite': 'jour'}}], 'engagementContinuiteFourniture': [{
                'dateSouscription': dt.date(2007, 5, 31), 'dateResiliation': dt.date(
                    2012, 3, 23), 'type': {'libelle': 'string', 'code': 'string'}, 'periodicite': {
                    'libelle': 'string', 'code': 'string'}, 'typesCoupures': {'libelle': 'string',
                                                                              'code': 'string'},
                'nbCoupuresBreves': 100, 'nbCoupuresLongues': 100,
                'nbTotalCoupures': 100, 'dateReferenceCoupures': dt.date(2014, 12, 18),
                'id': 201}], 'periodeObservation': [{'dateSouscription': dt.date(2005, 9,
                                                                                 5),
                                                     'dateResiliation': dt.date(2010, 2, 23),
                                                     'duree': {'valeur': Decimal(
                                                         '1000.000000000000000'), 'unite': 'semaine'}}],
            'calendrierFournisseur': [{
                'dateSouscription': dt.date(2013, 10, 31), 'dateResiliation':
                    dt.date(2018, 8, 10), 'calendrier': {'libelle': 'string',
                                                         'code': 'string'}, 'profilable': False,
                'periodeMobileAutorisee': False}]},
        'modificationsContractuellesEnCours': {'modificationContractuelleEnCours': [{
            'prestations': {'prestation': [{'fiche': {'libelle': 'string', 'code': 'string'},
                                            'option': {'libelle': 'string', 'code': 'string'},
                                            'cas': {'libelle': 'string',
                                                    'code': 'string'}, 'rang': 100,
                                            'dateEffetReelle': dt.date(2019, 3, 30),
                                            'dateEffetPrevue': dt.date(2001, 9, 30)}]}, 'demande': {'contratId':
                                                                                                        'string',
                                                                                                    'dateEffetSouhaitee': dt.date(
                                                                                                        2003, 7, 15),
                                                                                                    'clientFinal': {
                                                                                                        'categorie': {
                                                                                                            'libelle': 'string',
                                                                                                            'code': 'RES'},
                                                                                                        'typeResidence': {
                                                                                                            'libelle':
                                                                                                                'string',
                                                                                                            'code': 'PRP'},
                                                                                                        'refFournisseur': 'string',
                                                                                                        'personnePhysique': {
                                                                                                            'civilite': 'string',
                                                                                                            'nom': 'string',
                                                                                                            'prenom': 'string'},
                                                                                                        'personneMorale':
                                                                                                            None,
                                                                                                        'adressePostale': {
                                                                                                            'ligne1': 'string',
                                                                                                            'ligne2': 'string',
                                                                                                            'ligne3': 'string',
                                                                                                            'ligne4': 'string',
                                                                                                            'ligne5': 'string',
                                                                                                            'ligne6': 'string',
                                                                                                            'ligne7': 'string'},
                                                                                                        'coordonneesContact': {
                                                                                                            'numTelephone1': 'string',
                                                                                                            'numTelephone2': 'string',
                                                                                                            'numFax': 'string',
                                                                                                            'adresseEmail': 'string'}},
                                                                                                    'structureTarifaire': {
                                                                                                        'formuleTarifaireAcheminement': {
                                                                                                            'libelle': 'string',
                                                                                                            'code': 'string'},
                                                                                                        'longueUtilisation': {
                                                                                                            'contexte': {
                                                                                                                'libelle': 'string',
                                                                                                                'code': 'string'},
                                                                                                            'forfait': {
                                                                                                                'valeur': Decimal(
                                                                                                                    '1000.000000000000000'),
                                                                                                                'unite': 'ms'}},
                                                                                                        'codeTarifAcheminement': 'string',
                                                                                                        'puissanceSouscriteMax': {
                                                                                                            'valeur': Decimal(
                                                                                                                '1000.000000000000000'),
                                                                                                            'unite': 'kW'},
                                                                                                        'denivelePuissances':
                                                                                                            {
                                                                                                                'classesTemporelles': {
                                                                                                                    'classeTemporelle': [
                                                                                                                        {
                                                                                                                            'libelle': 'string',
                                                                                                                            'puissance': {
                                                                                                                                'valeur': Decimal(
                                                                                                                                    '1000.000000000000000'),
                                                                                                                                'unite': 'kVAR'},
                                                                                                                            'code': 'string'}]}},
                                                                                                        'calendrierFrn': {
                                                                                                            'libelle': 'string',
                                                                                                            'code': 'string'},
                                                                                                        'groupePeriodeMobile': {
                                                                                                            'libelle': 'string',
                                                                                                            'code': 'string'}}},
            'affaireId':
                'string'}]}, 'interventionsEnCours': {'interventionEnCours': [{'affaireId': [
            'string'], 'teleoperable': False, 'operations': {'operation': [{'libelle':
                                                                                'string', 'code': 'string'}],
                                                             'referencesDisco': {'objet': {'libelle': 'string',
                                                                                           'code': 'string'},
                                                                                 'nature': {'libelle': 'string',
                                                                                            'code': 'string'}}},
            'dateCreationAc': dt.date(2012, 5, 17), 'datePrevue': dt.date(2001,
                                                                          6, 26), 'heureDebut': dt.time(7, 28, 19),
            'heureFin': dt.time(13, 49,
                                34), 'creneauHorairePrevu': {'libelle': 'string', 'code': 'string'}}]},
        'historiqueAffaires': {'affaire': [{'prestation': {'fiche': {'libelle': 'string',
                                                                     'code': 'string'},
                                                           'option': {'libelle': 'string', 'code': 'string'},
                                                           'cas': {'libelle': 'string', 'code': 'string'}, 'rang': 100},
                                            'refFournisseur':
                                                'string', 'client': 'string',
                                            'nomCommercialActeurMarcheInitiateur': 'string',
                                            'dateEnvoi': dt.date(2005, 3, 29), 'dateEffet': dt.date(2003, 6, 10),
                                            'loginInitiateur': 'string',
                                            'etat': {'libelle': 'string', 'code': 'string'},
                                            'motifCloture': {'libelle': 'string', 'code': 'string'},
                                            'statut': {'libelle':
                                                           'string', 'code': 'ANNUL'}, 'id': 'string'}]},
        'elementsProchainesMesures': {
            'prochainCalculConsommation': {'nature': {'libelle': 'string', 'code': 'string'},
                                           'dateTheoriqueProchainCalculConsommation': dt.date(2015, 12, 31)},
            'dateTheoriqueProchainReleve': dt.date(2013, 9, 16)},
        'derniersIndexPublies': {'date': dt.date(2013, 10, 24), 'declencheur': {
            'libelle': 'string', 'code': 'string'}, 'nature': {'libelle': 'string',
                                                               'code': 'string'},
                                 'origine': {'libelle': 'string', 'code': 'string'},
                                 'grilleTurpe': {'calendrier': {'libelle': 'string', 'code': 'string'},
                                                 'classesTemporelles': {
                                                     'classeTemporelle': [{'libelle': 'string', 'index': [{
                                                         'valeur': Decimal('1000.000000000000000'), 'unite': 'string',
                                                         'grandeurPhysique':
                                                             {'libelle': 'string', 'code': 'string'}, 'phase': 100}],
                                                                           'code': 'string'}]}},
                                 'grilleFrn': {'calendrier': {'libelle': 'string', 'code': 'string'},
                                               'classesTemporelles': {
                                                   'classeTemporelle': [{'libelle': 'string', 'index': [{
                                                       'valeur': Decimal('1000.000000000000000'), 'unite': 'string',
                                                       'grandeurPhysique':
                                                           {'libelle': 'string', 'code': 'string'}, 'phase': 100}],
                                                                         'code': 'string'}]}}},
        'derniersIndexReleves': {'date': dt.date(2000, 9, 30), 'declencheur': {
            'libelle': 'string', 'code': 'string'}, 'nature': {'libelle': 'string',
                                                               'code': 'string'},
                                 'origine': {'libelle': 'string', 'code': 'string'},
                                 'grilleTurpe': {'calendrier': {'libelle': 'string', 'code': 'string'},
                                                 'classesTemporelles': {
                                                     'classeTemporelle': [{'libelle': 'string', 'index': [{
                                                         'valeur': Decimal('1000.000000000000000'), 'unite': 'string',
                                                         'grandeurPhysique':
                                                             {'libelle': 'string', 'code': 'string'}, 'phase': 100}],
                                                                           'code': 'string'}]}},
                                 'grilleFrn': {'calendrier': {'libelle': 'string', 'code': 'string'},
                                               'classesTemporelles': {
                                                   'classeTemporelle': [{'libelle': 'string', 'index': [{
                                                       'valeur': Decimal('1000.000000000000000'), 'unite': 'string',
                                                       'grandeurPhysique':
                                                           {'libelle': 'string', 'code': 'string'}, 'phase': 100}],
                                                                         'code': 'string'}]}}},
        'id': 'string'}}}

    def test_creation_message_correct(self):
        donnees = DonneesConsulterPoint('12345678911234')
        msg, _ = ConsulterPoint.consulter_donnees_point(self.connection, donnees, send=False)

        expected_msg = {
            'autorisationClient': True,
            'contratConcluNouveauClientSurSite': None,
            'donneesDemandees': {
                'donneesGeneralesPoint': True,
                'modificationsContractuellesEnCours': True,
                'interventionsEnCours': True,
                'historiqueAffaires': True,
                'elementsProchainesMesures': True,
                'derniersIndex': True
            },
            'pointId': '12345678911234',
            'loginUtilisateur': 'test@test.fr'}
        self.assertDictEqual(msg, expected_msg)

    def test_creation_message_mauvais_type_d_entree(self):
        donnees = DonneesConsulterPoint('12345678911234', donnees_generales=None)
        _, response = ConsulterPoint.consulter_donnees_point(self.connection, donnees)
        self.assertEqual(response['erreur'], "('Missing element donneesGeneralesPoint',)")

    @patch.object(zeep.helpers, 'serialize_object', raise_transport_errror)
    def test_connexion_echoue(self):
        donnees = DonneesConsulterPoint('12345678911234')
        _, response = ConsulterPoint.consulter_donnees_point(self.connection, donnees)
        self.assertEqual(response, {'erreur': "('une erreur inconnue est survenue',)", 'status': 'failed'})

    def test_connexion(self):
        donnees = DonneesConsulterPoint('12345678911234')
        _, response = ConsulterPoint.consulter_donnees_point(self.connection, donnees)

        self.assertDictEqual(response, self.expected_response)



import logging

from zeep.helpers import serialize_object

from enedis.connection.enedis_connection import EnedisConnection
from enedis.data_models.consulterdonneestechniquescontractuelles import ConsulterDonneesTechniquesContractuelles

logger = logging.getLogger(__name__)

class ConsulterDoneesTechniquesContractuelles:
    name = 'ConsultationDonneesTechniquesContractuelles-v1.0'
    ns = 'http://www.enedis.fr/sge/b2b/services/consulterdonneestechniquescontractuelles/v1.0'
    tn_binding = 'http://www.enedis.fr/sge/b2b/services/consultationdonneestechniquescontractuelles/v1.0'
    port_binding = 'ConsultationDonneesTechniquesContractuellesBinding'
    service_path = 'ConsultationDonneesTechniquesContractuelles/v1.0'

    @classmethod
    def consultation_donnees_techniques_contractuelles(cls, connection:EnedisConnection, donnees: ConsulterDonneesTechniquesContractuelles, send=True):
        message, response = None, None
        try:
            service, factory, client = connection.soap_service(cls.name, cls.ns, cls.port_binding, cls.service_path,
                                                           cls.tn_binding)

            donnees['loginUtilisateur'] = connection.login

            # Contrairement aux autres types, passer l'objet donnees directement ne fonctionne pas
            message = factory.ConsulterDonneesTechniquesContractuellesType(**donnees)

            if send:
                # Contrairement aux autres services, passer l'objet message directement ne fonctionne pas
                response = serialize_object(service.consulterDonneesTechniquesContractuelles(**{k:message[k] for k,v in donnees.items()}), dict)

            return serialize_object(message, dict), response
        except Exception as e:
            logger.exception("Erreur appel service")
            return message, {'erreur': str(e.args), 'status': 'failed'}


import logging
from pprint import pprint

from zeep.helpers import serialize_object

from enedis.connection.enedis_connection import EnedisConnection
from enedis.data_models.consulterdonneespoint import DonneesConsulterPoint

logger = logging.getLogger(__name__)


class ConsulterPoint:
    ns = 'http://www.enedis.fr/sge/b2b/services/consulterdonneespoint/v4.0'
    tn_binding = 'http://www.enedis.fr/sge/b2b/services/consultationpoint/v4.0'
    name = 'ConsultationPoint-v4.0'
    service_name = 'consulterDonneesPoint'
    service_path = 'ConsultationPoint/v4.0'
    port_binding = 'ConsultationPointBinding'

    @classmethod
    def consulter_donnees_point(cls, connection: EnedisConnection, donnees: DonneesConsulterPoint, send=True):
        message, response = None, None
        try:
            service, factory, client = connection.soap_service(cls.name, cls.ns, cls.port_binding, cls.service_path,
                                                       cls.tn_binding)

            donnees['loginUtilisateur'] = connection.login

            message = factory.ConsulterDonneesPointType(**donnees)

            if send:
                response = serialize_object(service.consulterDonneesPoint(**{k:message[k] for k,v in donnees.items()}), dict)

            return serialize_object(message, dict), response

        except Exception as e:
            logger.exception("Erreur appel service")
            return message, {'erreur': str(e.args), 'status': 'failed'}




import datetime as dt
from time import sleep

import pandas as pd

from enedis.services.commande_M023 import M023Base
from enedis.services.commande_acces_donnees_mesures import CommandeAccesDonneesMesures
from enedis.services.commander_arret_service_souscrit_mesures import CommanderArretServiceSouscritMesures
from enedis.services.commander_collecte_publication_mesures import CommanderCollectePublicationMesures
from enedis.services.consulter_donnees_techniques_contractuelles import ConsulterDoneesTechniquesContractuelles  # OK
from enedis.services.consulter_mesures import ConsulterMesures  # OK
from enedis.services.consulter_mesures_detaillees import ConsulterMesuresDetaillees  # OK
from enedis.services.recherche_services_souscrits_mesures import RechercheServicesSouscritsMesures
from enedis.services.rechercher_point import RecherchePoint  # OK
from enedis.data_models.M023 import DemandeHistoriqueMesuresFines, \
    DemandeHistoriqueDonneesFacturantes, DemandeInformationsTechniquesEtContractuelles
from enedis.data_models.commandeaccesdonneesmesures import Contrat, \
    DemandeAccesDonneesMesures, AccesDonnees, DonneesGeneralesAccesDonnees
from enedis.data_models.commanderarretservicesouscritmesures import \
    DemandeArretServiceSouscritMesures, ArretServiceSouscrit, DonneesGeneralesArretService
from enedis.data_models.commandercollectepublicationmesures import DemandeCollectePublicationMesure, \
    AccesMesures, DonneesGeneralesDemandeCollecte
from enedis.data_models.common import DeclarationAccordClient, PersonnePhysique
from enedis.data_models.consulterdonneestechniquescontractuelles import Point  # OK
from enedis.data_models.consultermesures import DonneesConsulterMesures  # OK
from enedis.data_models.consultermesuresdetaillees import \
    DemandeConsulterMesuresDetaillees  # OK
from enedis.data_models.recherchepoint import AdresseInstallation, Criteres  # OK

LIST_C2C4 = ['98800004935121', '98800001544168', '98800004938924', '98800006694381', '98800001220186']
LIST_C5 = ['25150217034354', '25825036170379', '25999131613803', '50086054270348', '25262662681289']

CAS_TEST = [{'function': ConsulterDoneesTechniquesContractuelles.consultation_donnees_techniques_contractuelles,
             'params': [Point(point_id='98800007059999', autorisation_client=True),
                        Point(point_id='25946599093143', autorisation_client=True),
                        Point(point_id='98800007059999', autorisation_client=False),
                        Point(point_id='25946599093143', autorisation_client=False),
                        Point(point_id='99999999999999')]
             },
            {'function': ConsulterMesures.consulter_mesures,
             'params': [DonneesConsulterMesures(point_id='30001610071843', autorisation_client=True),
                        DonneesConsulterMesures(point_id='25957452924301', autorisation_client=True),
                        DonneesConsulterMesures(point_id='30001610071843', autorisation_client=False),
                        ]
             },
            {'function': ConsulterMesuresDetaillees.consulter_mesures_detaillees,
             'params': [DemandeConsulterMesuresDetaillees('30001610071843', TypeDonneesM023.CDC, GrandeurPhysique.PA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.ACCORD_CLIENT),
                        DemandeConsulterMesuresDetaillees('25478147557460', TypeDonneesM023.CDC, GrandeurPhysique.PA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.ACCORD_CLIENT),

                        DemandeConsulterMesuresDetaillees('30001610071843', TypeDonneesM023.CDC,
                                                          GrandeurPhysique.PRI,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.ACCORD_CLIENT),

                        DemandeConsulterMesuresDetaillees('30001610071843',
                                                          TypeDonneesM023.ENERGIE,
                                                          GrandeurPhysique.EA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.ACCORD_CLIENT),

                        DemandeConsulterMesuresDetaillees('25478147557460',
                                                          TypeDonneesM023.ENERGIE,
                                                          GrandeurPhysique.EA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.ACCORD_CLIENT),

                        DemandeConsulterMesuresDetaillees('25478147557460',
                                                          TypeDonneesM023.PMAX,
                                                          GrandeurPhysique.PMA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.ACCORD_CLIENT, mesures_pas=MesuresPas.JOUR),

                        DemandeConsulterMesuresDetaillees('30001610071843',
                                                          TypeDonneesM023.INDEX,
                                                          GrandeurPhysique.EA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.ACCORD_CLIENT),

                        DemandeConsulterMesuresDetaillees('25478147557460',
                                                          TypeDonneesM023.INDEX,
                                                          GrandeurPhysique.EA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.ACCORD_CLIENT),

                        DemandeConsulterMesuresDetaillees('30001610071843',
                                                          TypeDonneesM023.INDEX,
                                                          GrandeurPhysique.EA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.SERVICE_ACCES),

                        DemandeConsulterMesuresDetaillees('25478147557460',
                                                          TypeDonneesM023.INDEX,
                                                          GrandeurPhysique.EA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 7)
                                                          , False, CadreAcces.SERVICE_ACCES),

                        DemandeConsulterMesuresDetaillees('25478147557460',
                                                          TypeDonneesM023.CDC,
                                                          GrandeurPhysique.PA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 9)
                                                          , False, CadreAcces.ACCORD_CLIENT),

                        DemandeConsulterMesuresDetaillees('25478147557460',
                                                          TypeDonneesM023.INDEX,
                                                          GrandeurPhysique.EA,
                                                          SensMesure.SOUTIRAGE, dt.date(2022, 4, 1), dt.date(2022, 4, 8)
                                                          , False, CadreAcces.SERVICE_ACCES)
                        ]
             },
            {'function': RecherchePoint.recherche_point,
             'params': [
                 Criteres(adresse_installation=AdresseInstallation(code_postal='34650', code_insee_commune='34231'),
                          domaine_tension_alimentation_code=DomaineTension.BTINF,
                          categorie_client_final_code=ClientFinalCategorieCode.RES),

                 Criteres(adresse_installation=AdresseInstallation(code_postal='84160', code_insee_commune='84042',
                                                                   numero_et_nom_voie='1 RUE DE LA MER'),
                          nom_client_final_ou_denomination_sociale='TEST', recherche_hors_perimetre=True),

                 Criteres(adresse_installation=AdresseInstallation(code_postal='84160', code_insee_commune='84042',
                                                                   numero_et_nom_voie='1 RUE DE LA MER'),
                          nom_client_final_ou_denomination_sociale='TES', recherche_hors_perimetre=True),

                 Criteres(adresse_installation=AdresseInstallation(code_postal='34650', code_insee_commune='34231'),
                          categorie_client_final_code=ClientFinalCategorieCode.RES),

                 Criteres(adresse_installation=AdresseInstallation(code_insee_commune='34231',
                                                                   numero_et_nom_voie='404 rue de la demande invalide'))

             ]
             },
            {'function': CommandeAccesDonneesMesures.commande_acces_donnees_mesures,
             'params': [DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('24380318190106', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.ENERGIE, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('98800002267746', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.ENERGIE, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('24380318190106', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.CDC, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('98800002267746', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.CDC, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('24380318190106', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.PMAX, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('24380318190106', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.INDEX, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('98800002267746', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.INDEX, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('24380318190106', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.ENERGIE, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=False))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('98800002267746', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2025, 1, 1),
                                                                TypeDonneesV1.ENERGIE, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=False))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('24380318190106', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2077, 1, 1),
                                                                TypeDonneesV1.ENERGIE, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True))),

                        DemandeAccesDonneesMesures(DonneesGeneralesAccesDonnees('98800002267746', Contrat()),
                                                   AccesDonnees(dt.date.today(), dt.date(2077, 1, 1),
                                                                TypeDonneesV1.ENERGIE, TypeSite.INJECTION,
                                                                DeclarationAccordClient(PersonnePhysique('Michu'), accord=True)))
                        ]
             },
            {'function': CommanderCollectePublicationMesures.commander_collecte_publication,
             'params': [
                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('25884515170669'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(
                                                  PersonnePhysique('Michu'),
                                                  accord=True),
                                              TypeDonneesV1.CDC,
                                              True,
                                              False,
                                              PasMesures.P30MIN,
                                              transmission_recurrente=True,
                                              periodicite_transmission=PeriodiciteTransmission.QUOTIDIENNE)),
                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('98800000000246'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=True),
                                              TypeDonneesV1.CDC, True, False,
                                              PasMesures.P10MIN,
                                              transmission_recurrente=True,
                                              periodicite_transmission=PeriodiciteTransmission.QUOTIDIENNE,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('25884515170669'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=True),
                                              TypeDonneesV1.CDC, True, False,
                                              PasMesures.P30MIN,
                                              transmission_recurrente=False,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('98800000000246'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=True),
                                              TypeDonneesV1.CDC, True, False,
                                              PasMesures.P10MIN,
                                              transmission_recurrente=False,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('25884515170669'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=True),
                                              TypeDonneesV1.INDEX, True, False,
                                              PasMesures.QUOTIDIEN,
                                              transmission_recurrente=True,
                                              periodicite_transmission=PeriodiciteTransmission.QUOTIDIENNE,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('98800000000246'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=True),
                                              TypeDonneesV1.INDEX, True, False,
                                              PasMesures.QUOTIDIEN,
                                              transmission_recurrente=True,
                                              periodicite_transmission=PeriodiciteTransmission.QUOTIDIENNE,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('25884515170669'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=4*365),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=True),
                                              TypeDonneesV1.CDC, True, False,
                                              PasMesures.P30MIN,
                                              transmission_recurrente=True,
                                              periodicite_transmission=PeriodiciteTransmission.QUOTIDIENNE,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('25884515170669'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=False),
                                              TypeDonneesV1.CDC, True, False,
                                              PasMesures.P30MIN,
                                              transmission_recurrente=False,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('98800000000246'),
                                                  AccesMesures(dt.date.today() + dt.timedelta(days=10), dt.date.today() +
                                              dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=False),
                                              TypeDonneesV1.CDC, True, False,
                                              PasMesures.P10MIN,
                                              transmission_recurrente=False,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('25884515170669'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=False),
                                              TypeDonneesV1.INDEX, True, False,
                                              PasMesures.QUOTIDIEN,
                                              transmission_recurrente=True,
                                              periodicite_transmission=PeriodiciteTransmission.QUOTIDIENNE,
                                              mesures_corrigees=False)),

                 DemandeCollectePublicationMesure(DonneesGeneralesDemandeCollecte('98800000000246'),
                                                  AccesMesures(dt.date.today(), dt.date.today() + dt.timedelta(days=200),
                                              DeclarationAccordClient(PersonnePhysique('Michu'), accord=False),
                                              TypeDonneesV1.INDEX, True, False,
                                              PasMesures.QUOTIDIEN,
                                              transmission_recurrente=True,
                                              periodicite_transmission=PeriodiciteTransmission.QUOTIDIENNE,
                                              mesures_corrigees=False))

             ]},
            {'function': RechercheServicesSouscritsMesures.rechercher_services_souscrit_mesures,
             'params': ['25884515170669',
                        '98800000000246']
             },
            {'function': CommanderArretServiceSouscritMesures.commander_arret_service_souscrit_mesures,
             'params': [DemandeArretServiceSouscritMesures(DonneesGeneralesArretService('25884515170669'), ArretServiceSouscrit('12')),
                        DemandeArretServiceSouscritMesures(DonneesGeneralesArretService('98800000000246'), ArretServiceSouscrit('12'))]
             },

            {'function': M023Base.m023,
             'params': [DemandeHistoriqueMesuresFines(dt.date(2023, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.ENERGIE, LIST_C5,
                                                      FormatsM023.JSON, False),
                        DemandeHistoriqueMesuresFines(dt.date(2023, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.ENERGIE, LIST_C2C4,
                                                      FormatsM023.CSV, True),
                        DemandeHistoriqueMesuresFines(dt.date(2023, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.CDC, ['25150217034354'],
                                                      FormatsM023.CSV, False),
                        DemandeHistoriqueMesuresFines(dt.date(2023, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.CDC, ['98800004935121'],
                                                      FormatsM023.CSV, True),
                        DemandeHistoriqueMesuresFines(dt.date(2023, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.PMAX, ['25150217034354'],
                                                      FormatsM023.CSV, False),
                        DemandeHistoriqueMesuresFines(dt.date(2023, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.PMAX, ['98800004935121'],
                                                      FormatsM023.CSV, True),
                        DemandeHistoriqueMesuresFines(dt.date(2023, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.INDEX, LIST_C5,
                                                      FormatsM023.JSON, False),
                        DemandeHistoriqueMesuresFines(dt.date(2023, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.INDEX, LIST_C2C4,
                                                      FormatsM023.CSV, True),
                        DemandeHistoriqueMesuresFines(dt.date(2020, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.CDC, LIST_C5,
                                                      FormatsM023.CSV, False),
                        DemandeHistoriqueMesuresFines(dt.date(2020, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.CDC, LIST_C2C4,
                                                      FormatsM023.CSV, True),
                        DemandeHistoriqueMesuresFines(dt.date(2019, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.INDEX, LIST_C5,
                                                      FormatsM023.CSV, False),
                        DemandeHistoriqueMesuresFines(dt.date(2019, 1, 1),
                                                      dt.date(2023, 6, 1),
                                                      CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                      TypeDonneesM023.INDEX, LIST_C2C4,
                                                      FormatsM023.CSV, True),

                        DemandeHistoriqueDonneesFacturantes(dt.date(2023, 1, 1),
                                                            dt.date(2023, 6, 1),
                                                            CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                            LIST_C5,
                                                            FormatsM023.CSV),
                        DemandeHistoriqueDonneesFacturantes(dt.date(2023, 1, 1),
                                                            dt.date(2023, 6, 1),
                                                            CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                            LIST_C2C4,
                                                            FormatsM023.CSV),

                        DemandeHistoriqueDonneesFacturantes(dt.date(2023, 6, 1),
                                                            dt.date(2023, 1, 1),
                                                            CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                            LIST_C5,
                                                            FormatsM023.CSV),
                        DemandeHistoriqueDonneesFacturantes(dt.date(2023, 6, 1),
                                                            dt.date(2023, 1, 1),
                                                            CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                            LIST_C2C4,
                                                            FormatsM023.CSV),

                        DemandeInformationsTechniquesEtContractuelles(CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                                      LIST_C5,
                                                                      FormatsM023.CSV),
                        DemandeInformationsTechniquesEtContractuelles(CadreAcces.ACCORD_CLIENT, SensMesure.SOUTIRAGE,
                                                                      LIST_C2C4,
                                                                      FormatsM023.CSV),
                        ]
             },
            ]


def run():
    results = dict(nom_service=[], date_appel=[], date_reception=[], dict_params=[], message_recu=[])
    for test in CAS_TEST:
        for param in test['params']:
            date_envoi = dt.datetime.now()
            f = test['function'](param)
            date_reception = dt.datetime.now()
            results['nom_service'].append(test['function'].__name__)
            results['date_appel'].append(date_envoi)
            results['date_reception'].append(date_reception)
            results['dict_params'].append(param)
            results['message_recu'].append(f)
            sleep(1)
    results_df = pd.DataFrame(results)
    results_df.to_csv('resultats_homologation.csv')



from unittest.mock import patch

import zeep
from zeep.helpers import serialize_object

from enedis.data_models.commanderarretservicesouscritmesures import *
from enedis.services.commander_arret_service_souscrit_mesures import CommanderArretServiceSouscritMesures
from proxy.tests.services.ServicesTestCase import ServicesTestCase, raise_transport_errror, raise_creation_error


class TestCommanderArretServicesSouscritsMesures(ServicesTestCase):
    maxDiff = None

    def test_creation_message(self):
        arret_service_souscrit = ArretServiceSouscrit('12')
        donnees_generales = DonneesGeneralesArretService('12345678911234')
        demande_arret = DemandeArretServiceSouscritMesures(donnees_generales, arret_service_souscrit)

        msg, _ = CommanderArretServiceSouscritMesures.commander_arret_service_souscrit_mesures(self.connection, demande_arret, send=False)

        expected_msg = {'demande': {
            'donneesGenerales': {
                'objetCode': 'ASS',
                'pointId': '12345678911234',
                'initiateurLogin': 'test@test.fr',
                'contratId': '1111111'
            },
            'arretServiceSouscrit': {
                'serviceSouscritId': '12'}}}

        self.assertDictEqual(msg, expected_msg)

    def test_transmission_message(self):
        arret_service_souscrit = ArretServiceSouscrit('12')
        donnees_generales = DonneesGeneralesArretService('12345678911234')
        demande_arret = DemandeArretServiceSouscritMesures(donnees_generales, arret_service_souscrit)

        msg, response = CommanderArretServiceSouscritMesures.commander_arret_service_souscrit_mesures(self.connection, demande_arret)

        expected_response = {'header': {
            'acquittement': None
        },
            'body': {
                'affaireId': 'string',
                'prestations': {
                    'prestation': [
                        {
                            'rang': 100,
                            'fiche': {
                                'libelle': 'string', 'code': 'string'
                            },
                            'option': {
                                'libelle': 'string', 'code': 'string'
                            },
                            'cas': {
                                'libelle': 'string', 'code': 'string'
                            }
                        }
                    ]
                }
            }
        }
        self.assertDictEqual(response, expected_response)

    @patch.object(zeep.helpers, 'serialize_object', raise_transport_errror)
    def test_connexion_echoue(self):
        arret_service_souscrit = ArretServiceSouscrit('12')
        donnees_generales = DonneesGeneralesArretService('12345678911234')
        demande_arret = DemandeArretServiceSouscritMesures(donnees_generales, arret_service_souscrit)
        msg, response = CommanderArretServiceSouscritMesures.commander_arret_service_souscrit_mesures(self.connection, demande_arret)
        self.assertEqual(response, {'erreur': "('une erreur inconnue est survenue',)", 'status': 'failed'})

